export default rehypePrism;
export type Node = import('hast').Node & {
    properties: any;
};
export type Parent = import('hast').Parent & {
    properties: any;
};
export type Root = import('hast').Root;
export type Visitor = import('unist-util-visit').Visitor<Node>;
/**
 * options
 * Configuration.
 */
export type Options = {
    /**
     * Set `showLineNumbers` to `true` to always display line number
     */
    showLineNumbers?: boolean;
    /**
     * Set `ignoreMissing` to `true` to ignore unsupported languages and line highlighting when no language is specified
     */
    ignoreMissing?: boolean;
};
/**
 * Rehype prism plugin generator that highlights code blocks with refractor (prismjs)
 *
 * Pass in your own refractor object with the required languages registered:
 * https://github.com/wooorm/refractor#refractorregistersyntax
 *
 * @param {import('refractor/lib/core').Refractor} refractor
 * @return {import('unified').Plugin<[Options?], Root>}
 */
export function rehypePrismGenerator(refractor: import('refractor/lib/core').Refractor): import('unified').Plugin<[Options?], Root>;
/**
 * Rehype prism plugin that highlights code blocks with refractor (prismjs)
 * Supported languages: https://github.com/wooorm/refractor#data
 *
 * Consider using rehypePrismGenerator to generate a plugin
 * that supports your required languages.
 */
export const rehypePrismCommon: import("unified").Plugin<[Options?], import("hast").Root, import("hast").Root>;
/**
 * Rehype prism plugin that highlights code blocks with refractor (prismjs)
 * This supports all the languages and should be used on the server side.
 *
 * Consider using rehypePrismCommon or rehypePrismGenerator to generate a plugin
 * that supports your required languages.
 */
declare const rehypePrism: import("unified").Plugin<[Options?], import("hast").Root, import("hast").Root>;
